PCB Environment: Action::Result Struct Reference

PCB Environment 2

Loading...
Searching...
No Matches
Public Member Functions | Data Fields
Action::Result Struct Reference

## Public Member Functions
| Result (Reward r, bool ok, bool t=false)
bool | operator< (const Result &) const
bool | operator> (const Result &that) const
bool | operator== (const Result &) const
std::string | str () const

## Data Fields
Reward | R
RouterResult | Router
bool | Success {true}
bool | Termination {false}

The documentation for this struct was generated from the following file:

- /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/RL/Action.hpp